@@ -1,8 +1,8 @@
 import logging
 import struct
 import warnings
-from typing import Any, Dict, List, Optional, Sequence, Tuple
 from enum import Enum
+from typing import Any, Dict, List, Optional, Sequence, Tuple
 
 import numpy as np
 
@@ -12,7 +12,9 @@ from qcodes.data.data_set import DataSet
 from qcodes.instrument.base import Instrument, Parameter
 from qcodes.instrument.channel import InstrumentChannel
 from qcodes.instrument.parameter import (
-    ArrayParameter, ParameterWithSetpoints, ParamRawDataType
+    ArrayParameter,
+    ParameterWithSetpoints,
+    ParamRawDataType,
 )
 from qcodes.measure import Measure
 from qcodes.utils.helpers import create_on_off_val_mapping
@@ -26,12 +28,15 @@ class LuaSweepParameter(ArrayParameter):
     deployed Lua script sweep.
     """
 
-    def __init__(self, name: str, instrument: Instrument) -> None:
+    def __init__(self, name: str, instrument: Instrument, **kwargs: Any) -> None:
 
-        super().__init__(name=name,
-                         shape=(1,),
-                         docstring='Holds a sweep',
-                         instrument=instrument)
+        super().__init__(
+            name=name,
+            shape=(1,),
+            docstring="Holds a sweep",
+            instrument=instrument,
+            **kwargs,
+        )
 
     def prepareSweep(self, start: float, stop: float, steps: int,
                      mode: str) -> None:
@@ -213,6 +218,20 @@ class _ParameterWithStatus(Parameter):
     def measurement_status(self) -> Optional[MeasurementStatus]:
         return self._measurement_status
 
+    @staticmethod
+    def _parse_response(data: str) -> Tuple[float, MeasurementStatus]:
+
+        value, meas_status = data.split('\t')
+
+        status_bits = [int(i) for i in bin(
+            int(float(meas_status))
+        ).replace('0b', '').zfill(16)[::-1]]
+
+        if status_bits[1]:
+            return float(value), MeasurementStatus.COMPLIANCE_ERROR
+        else:
+            return float(value), MeasurementStatus.NORMAL
+
     def snapshot_base(self, update: Optional[bool] = True,
                       params_to_skip_update: Optional[Sequence[str]] = None
                       ) -> Dict[Any, Any]:
@@ -228,23 +247,6 @@ class _ParameterWithStatus(Parameter):
 
 class _MeasurementCurrentParameter(_ParameterWithStatus):
 
-    def __init__(self, *args: Any, **kwargs: Any):
-        super().__init__(*args, **kwargs)
-
-    @staticmethod
-    def _parse_response(data: str) -> Tuple[float, MeasurementStatus]:
-
-        value, meas_status = data.split('\t')
-
-        status_bits = [int(i) for i in bin(
-            int(float(meas_status))
-        ).replace('0b', '').zfill(16)[::-1]]
-
-        if status_bits[1]:
-            return float(value), MeasurementStatus.COMPLIANCE_ERROR
-        else:
-            return float(value), MeasurementStatus.NORMAL
-
     def get_raw(self) -> ParamRawDataType:
         assert isinstance(self.instrument, KeithleyChannel)
         assert isinstance(self.root_instrument, Keithley_2600)
@@ -261,6 +263,24 @@ class _MeasurementCurrentParameter(_ParameterWithStatus):
         return value
 
 
+class _MeasurementVoltageParameter(_ParameterWithStatus):
+
+    def get_raw(self) -> ParamRawDataType:
+        assert isinstance(self.instrument, KeithleyChannel)
+        assert isinstance(self.root_instrument, Keithley_2600)
+
+        smu = self.instrument
+        channel = self.instrument.channel
+
+        data = smu.ask(f'{channel}.measure.v(), '
+                       f'status.measurement.instrument.{channel}.condition')
+        value, status = self._parse_response(data)
+
+        self._measurement_status = status
+
+        return value
+
+
 class KeithleyChannel(InstrumentChannel):
     """
     Class to hold the two Keithley channels, i.e.
@@ -291,11 +311,11 @@ class KeithleyChannel(InstrumentChannel):
         ilimit_minmax = self.parent._ilimit_minmax
 
         self.add_parameter('volt',
-                           get_cmd=f'{channel}.measure.v()',
-                           get_parser=float,
+                           parameter_class=_MeasurementVoltageParameter,
                            set_cmd=f'{channel}.source.levelv={{:.12f}}',
                            label='Voltage',
-                           unit='V')
+                           unit='V',
+                           snapshot_get=False)
 
         self.add_parameter('curr',
                            parameter_class=_MeasurementCurrentParameter,
